aboutsummaryrefslogtreecommitdiff
path: root/discord/calls.py
diff options
context:
space:
mode:
authorRapptz <[email protected]>2016-10-17 18:25:23 -0400
committerRapptz <[email protected]>2017-01-03 09:51:54 -0500
commitd1d54a468a88323a8ef7798ff084a1371d5893ec (patch)
tree21dd315df95acd2c8d6cf63cc51fa4cadc0c7155 /discord/calls.py
parentStateful Message and remove Invite.xkcd since it is removed. (diff)
downloaddiscord.py-d1d54a468a88323a8ef7798ff084a1371d5893ec.tar.xz
discord.py-d1d54a468a88323a8ef7798ff084a1371d5893ec.zip
Rename Server to Guild everywhere.
Diffstat (limited to 'discord/calls.py')
-rw-r--r--discord/calls.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/discord/calls.py b/discord/calls.py
index 0925f713..334f1d75 100644
--- a/discord/calls.py
+++ b/discord/calls.py
@@ -26,7 +26,7 @@ DEALINGS IN THE SOFTWARE.
from . import utils
import datetime
-from .enums import ServerRegion, try_enum
+from .enums import GuildRegion, try_enum
from .member import VoiceState
class CallMessage:
@@ -90,8 +90,8 @@ class GroupCall:
Denotes if this group call is unavailable.
ringing: List[:class:`User`]
A list of users that are currently being rung to join the call.
- region: :class:`ServerRegion`
- The server region the group call is being hosted on.
+ region: :class:`GuildRegion`
+ The guild region the group call is being hosted on.
"""
def __init__(self, **kwargs):
@@ -105,7 +105,7 @@ class GroupCall:
self._update(**kwargs)
def _update(self, **kwargs):
- self.region = try_enum(ServerRegion, kwargs.get('region'))
+ self.region = try_enum(GuildRegion, kwargs.get('region'))
lookup = {u.id: u for u in self.call.channel.recipients}
me = self.call.channel.me
lookup[me.id] = me